@@ -10,6 +10,12 @@ use std::{
     os::raw::{c_char, c_float, c_int, c_void},
     ptr,
 };
+#[cfg(feature = "clib")]
+pub mod deps {
+    pub use cpal;
+    pub use nstd_fs;
+    pub use rodio;
+}
 
 /// Represents an audio host.
 pub type NSTDAudioHost = *mut Host;
@@ -119,7 +125,7 @@ pub unsafe extern "C" fn nstd_std_audio_device_name(device: NSTDAudioDevice) ->
 #[inline]
 #[cfg_attr(feature = "clib", no_mangle)]
 pub unsafe extern "C" fn nstd_std_audio_device_free_name(name: *mut *mut c_char) {
-    CString::from_raw(*name);
+    drop(CString::from_raw(*name));
     *name = ptr::null_mut();
 }
 
